@@ -23,7 +23,7 @@ This function requires a integer number and return
 a list of prime components of this number
 """
 def primeComponents(number):
-	pComponents = set([1,number])
+	pComponents = set([1])
 	while(True):
 		if(isPrime(number) == False):
 			pComponents.add(firstDivisor)
@@ -32,4 +32,6 @@ def primeComponents(number):
 			pComponents.add(number)
 			return sorted(list(pComponents))
 
+print(primeComponents(11))
+
 
